@@ -12,8 +12,8 @@ class Test(TestCase):
         task_string = json_encode(task)
         expected_string = '{"_type": "task", "uuid": "uuid", "name": "name", "product_uuid": "product_uuid", ' \
                           '"pose": {"_type": "pose", "name": "", "position": {"_type": "vector3", "x": 0.0, ' \
-                          '"y": 0.0, "z": 0.0}, "rotation": {"_type": "vector3", "x": 0.0, "y": 0.0, "z": 0.0}}, ' \
-                          '"axis_angle": {"_type": "axis_angle", "angle": 0.0, "x": 1, "y": 0, "z": 0}, ' \
+                          '"y": 0.0, "z": 0.0}, "rotation": {"_type": "vector3", "x": 0.0, "y": 0.0, "z": 0.0}' \
+                          ', "axis_angle": {"_type": "axis_angle", "angle": 0.0, "x": 1, "y": 0, "z": 0}}, ' \
                           '"automated": false, "conditions": [], "conditions_fulfilled": true, "description": "", ' \
                           '"status": "waiting"}'
 
